@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2019 Vlad Zahorodnii <vladzzag@gmail.com>
+    Copyright (C) 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 
     formatBootTimestamp is based on TimeUtil class:
     Copyright (C) 2014 Gregor Mi <codestruct@posteo.org>
@@ -26,6 +26,7 @@
 
 #include <QLocale>
 #include <QTime>
+#include <QFontMetrics>
 
 #include <cmath>
 
@@ -77,6 +78,7 @@ static KLocalizedString unitFormat(Unit unit)
     const static KLocalizedString W = ki18nc("Watts unit symbol", "%1 W");
     const static KLocalizedString Wh = ki18nc("Watt-hours unit symbol", "%1 Wh");
     const static KLocalizedString rate = ki18nc("Rate unit symbol", "%1 s⁻¹");
+    const static KLocalizedString A = ki18nc("Ampere unit symbol", "%1 A");
     const static KLocalizedString unitless = ki18nc("Unitless", "%1");
 
     switch (unit) {
@@ -137,6 +139,8 @@ static KLocalizedString unitFormat(Unit unit)
         return W;
     case UnitWattHour:
         return Wh;
+    case UnitAmpere:
+        return A;
 
     default:
         return unitless;
@@ -168,6 +172,7 @@ static int unitOrder(Unit unit)
     case UnitPetaHertz:
     case UnitWatt:
     case UnitWattHour:
+    case UnitAmpere:
         return 1000;
 
     default:
@@ -307,6 +312,7 @@ QString Formatter::formatValue(const QVariant &value, Unit unit, MetricPrefix ta
     case UnitVolt:
     case UnitWatt:
     case UnitSecond:
+    case UnitAmpere:
         return formatNumber(value, unit, targetPrefix, options);
 
     case UnitBootTimestamp:
@@ -381,10 +387,38 @@ QString Formatter::symbol(Unit unit)
         return i18nc("Watt-hours unit symbol", "Wh");
     case UnitRate:
         return i18nc("Rate unit symbol", "s⁻¹");
+    case UnitAmpere:
+        return i18nc("Ampere unit symbol", "A");
 
     default:
         return QString();
     }
 }
 
+qreal Formatter::maximumLength(Unit unit, const QFont &font)
+{
+    auto order = unitOrder(unit);
+
+    QString maximum;
+    switch (unitBase(unit)) {
+    case UnitByte:
+        maximum = formatValue(order - 0.5, UnitMegaByte, MetricPrefixMega);
+        break;
+    case UnitByteRate:
+        maximum = formatValue(order - 0.5, UnitMegaByteRate, MetricPrefixMega);
+        break;
+    case UnitHertz:
+        maximum = formatValue(order - 0.5, UnitMegaHertz, MetricPrefixMega);
+        break;
+    case UnitPercent:
+        maximum = formatValue(9999.9, UnitPercent);
+        break;
+    default:
+        return -1.0;
+    }
+
+    auto metrics = QFontMetrics{font};
+    return metrics.horizontalAdvance(maximum);
+}
+
 } // namespace KSysGuard
