@@ -235,32 +235,32 @@ QSet<long> ProcessesLocal::getAllPids( )
     return pids;
 }
 
-bool ProcessesLocal::sendSignal(long pid, int sig) {
+Processes::Error ProcessesLocal::sendSignal(long pid, int sig) {
     if ( kill( (pid_t)pid, sig ) ) {
 	//Kill failed
-        return false;
+        return Processes::Unknown;
     }
-    return true;
+    return Processes::NoError;
 }
 
-bool ProcessesLocal::setNiceness(long pid, int priority) {
+Processes::Error ProcessesLocal::setNiceness(long pid, int priority) {
     if ( setpriority( PRIO_PROCESS, pid, priority ) ) {
 	    //set niceness failed
-	    return false;
+	    return Processes::Unknown;
     }
-    return true;
+    return Processes::NoError;
 }
 
-bool ProcessesLocal::setScheduler(long pid, int priorityClass, int priority)
+Processes::Error ProcessesLocal::setScheduler(long pid, int priorityClass, int priority)
 {
     if(priorityClass == KSysGuard::Process::Other || priorityClass == KSysGuard::Process::Batch)
 	    priority = 0;
-    if(pid <= 0) return false; // check the parameters
-	    return false;
+    if(pid <= 0) return Processes::InvalidPid; // check the parameters
+	    return Processes::NotSupported;
 }
 
-bool ProcessesLocal::setIoNiceness(long pid, int priorityClass, int priority) {
-    return false; //Not yet supported
+Processes::Error ProcessesLocal::setIoNiceness(long pid, int priorityClass, int priority) {
+    return Processes::NotSupported; //Not yet supported
 }
 
 bool ProcessesLocal::supportsIoNiceness() {
